Struct amazon_sp_aplus_content::models::standard_four_image_text_quadrant_module::StandardFourImageTextQuadrantModule
source · [−]pub struct StandardFourImageTextQuadrantModule {
pub block1: Box<StandardImageTextBlock>,
pub block2: Box<StandardImageTextBlock>,
pub block3: Box<StandardImageTextBlock>,
pub block4: Box<StandardImageTextBlock>,
}Expand description
StandardFourImageTextQuadrantModule : Four standard images with text, presented on a grid of four quadrants.
Fields
block1: Box<StandardImageTextBlock>block2: Box<StandardImageTextBlock>block3: Box<StandardImageTextBlock>block4: Box<StandardImageTextBlock>Implementations
sourceimpl StandardFourImageTextQuadrantModule
impl StandardFourImageTextQuadrantModule
sourcepub fn new(
block1: StandardImageTextBlock,
block2: StandardImageTextBlock,
block3: StandardImageTextBlock,
block4: StandardImageTextBlock
) -> StandardFourImageTextQuadrantModule
pub fn new(
block1: StandardImageTextBlock,
block2: StandardImageTextBlock,
block3: StandardImageTextBlock,
block4: StandardImageTextBlock
) -> StandardFourImageTextQuadrantModule
Four standard images with text, presented on a grid of four quadrants.